@@ -10,9 +10,9 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from django.urls import reverse
+from unittest import mock
 
-import mock
+from django.urls import reverse
 
 from senlin_dashboard import api
 from senlin_dashboard.test import helpers as test
