@@ -12,7 +12,7 @@
 
 from django.conf import settings
 from django.urls import re_path
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from horizon.browsers.views import AngularIndexView
 
