@@ -11,8 +11,8 @@
 # limitations under the License.
 
 from django.urls import reverse_lazy
-from django.utils.translation import ugettext_lazy as _
-from django.utils.translation import ungettext_lazy
+from django.utils.translation import gettext_lazy as _
+from django.utils.translation import ngettext_lazy
 
 from horizon import tables
 from horizon.utils import filters
@@ -33,7 +33,7 @@ class DeleteReceiver(tables.DeleteAction):
 
     @staticmethod
     def action_present(count):
-        return ungettext_lazy(
+        return ngettext_lazy(
             u"Delete Receiver",
             u"Delete Receivers",
             count
@@ -41,7 +41,7 @@ class DeleteReceiver(tables.DeleteAction):
 
     @staticmethod
     def action_past(count):
-        return ungettext_lazy(
+        return ngettext_lazy(
             u"Deleted Receiver",
             u"Deleted Receivers",
             count
